@@ -6,7 +6,7 @@
 ;; Modified: 20 Jun 1995
 ;; Version: 1.2.4
 ;; Keywords: extensions, languages, tools
-;; $Revision: 1.1 $
+;; $Revision: 1.2 $
 
 ;; This file is part of GNU Emacs.
 
@@ -159,7 +159,7 @@ setting it to '(upcase), for example.")
 (defvar tempo-local-tags '((tempo-tags . nil))
   "A list of locally installed tag completion lists.
 It is a association list where the car of every element is a symbol
-whose varable value is a template list. The cdr part, if non-nil, is a
+whose variable value is a template list. The cdr part, if non-nil, is a
 function or a regexp that defines the string to match. See the
 documentation for the function `tempo-complete-tag' for more info.
 
@@ -196,7 +196,7 @@ should be replaced with a template.")
 (defvar tempo-user-elements nil
   "Element handlers for user-defined elements.
 A list of symbols which are bound to functions that take one argument.
-This function should return somthing to be sent to `tempo-insert' if
+This function should return something to be sent to `tempo-insert' if
 it recognizes the argument, and NIL otherwise")
 
 (defvar tempo-named-insertions nil
@@ -259,7 +259,7 @@ The elements in ELEMENTS can be of several types:
  - The symbol 'r. If `tempo-insert' is called with ON-REGION non-nil
    the current region is placed here. Otherwise it works like 'p.
  - (p PROMPT <NAME> <NOINSERT>) If `tempo-interactive' is non-nil, the
-   user is prompted in the minbuffer with PROMPT for a string to be
+   user is prompted in the minibuffer with PROMPT for a string to be
    inserted. If the optional parameter NAME is non-nil, the text is
    saved for later insertion with the `s' tag. If there already is
    something saved under NAME that value is used instead and no
@@ -620,7 +620,7 @@ or to `tempo-tags' if TAG-LIST is nil."
 TAG-LIST is a symbol whose variable value is a tag list created with
 `tempo-add-tag'.
 
-COMPLETION-FUNCTION is an obsolete option for specifyingis an optional
+COMPLETION-FUNCTION is an obsolete option for specifying an optional
 function or string that is used by `\\[tempo-complete-tag]' to find a
 string to match the tag against. It has the same definition as the
 variable `tempo-match-finder'. In this version, supplying a
